@@ -85,6 +85,7 @@ struct _MetaDisplay
   Display *xdisplay;
 
   Window leader_window;
+  Window timestamp_pinging_window;
   
   Atom atom_net_wm_name;
   Atom atom_wm_protocols;
@@ -180,6 +181,7 @@ struct _MetaDisplay
   Atom atom_metacity_version;
   Atom atom_net_wm_visible_name;
   Atom atom_net_wm_visible_icon_name;
+  Atom atom_net_wm_user_time_window;
 
   /* This is the actual window from focus events,
    * not the one we last set
@@ -264,6 +266,7 @@ struct _MetaDisplay
   guint       grab_have_keyboard : 1;
   guint       grab_wireframe_active : 1;
   guint       grab_was_cancelled : 1;    /* Only used in wireframe mode */
+  guint       grab_frame_action : 1;
   MetaRectangle grab_wireframe_rect;
   MetaRectangle grab_wireframe_last_xor_rect;
   MetaRectangle grab_initial_window_pos;
@@ -446,6 +449,7 @@ gboolean meta_display_begin_grab_op (MetaDisplay *display,
                                      MetaWindow  *window,
                                      MetaGrabOp   op,
                                      gboolean     pointer_already_grabbed,
+                                     gboolean     frame_action,
                                      int          event_serial,
                                      int          button,
                                      gulong       modmask,
