@@ -1200,7 +1200,7 @@ meta_frame_titlebar_event (MetaUIFrame    *frame,
   
   switch (action)
     {
-    case META_ACTION_DOUBLE_CLICK_TITLEBAR_TOGGLE_SHADE:
+    case META_ACTION_TITLEBAR_TOGGLE_SHADE:
       {
         flags = meta_core_get_frame_flags (gdk_display, frame->xwindow);
         
@@ -1218,7 +1218,7 @@ meta_frame_titlebar_event (MetaUIFrame    *frame,
       }
       break;          
       
-    case META_ACTION_DOUBLE_CLICK_TITLEBAR_TOGGLE_MAXIMIZE:
+    case META_ACTION_TITLEBAR_TOGGLE_MAXIMIZE:
       {
         flags = meta_core_get_frame_flags (gdk_display, frame->xwindow);
         
@@ -1229,7 +1229,7 @@ meta_frame_titlebar_event (MetaUIFrame    *frame,
       }
       break;
 
-    case META_ACTION_DOUBLE_CLICK_TITLEBAR_MINIMIZE:
+    case META_ACTION_TITLEBAR_MINIMIZE:
       {
         flags = meta_core_get_frame_flags (gdk_display, frame->xwindow);
         
@@ -1240,11 +1240,26 @@ meta_frame_titlebar_event (MetaUIFrame    *frame,
       }
       break;
 
-    case META_ACTION_DOUBLE_CLICK_TITLEBAR_NONE:
+    case META_ACTION_TITLEBAR_NONE:
       /* Yaay, a sane user that doesn't use that other weird crap! */
       break;
+    
+    case META_ACTION_TITLEBAR_LOWER:
+      meta_core_user_lower_and_unfocus (gdk_display,
+                                        frame->xwindow,
+                                        event->time);
+      break;
 
-    case META_ACTION_DOUBLE_CLICK_TITLEBAR_LAST:
+    case META_ACTION_TITLEBAR_MENU:
+      meta_core_show_window_menu (gdk_display,
+                                  frame->xwindow,
+                                  event->x_root,
+                                  event->y_root,
+                                  event->button,
+                                  event->time);
+      break;
+
+    case META_ACTION_TITLEBAR_LAST:
       break;
     }
   
@@ -1264,23 +1279,18 @@ static gboolean
 meta_frame_middle_click_event (MetaUIFrame    *frame,
                                GdkEventButton *event)
 {
-  meta_core_user_lower_and_unfocus (gdk_display,
-                                    frame->xwindow,
-                                    event->time);
-  return TRUE;
+  int action = meta_prefs_get_action_middle_click_titlebar();
+  
+  return meta_frame_titlebar_event (frame, event, action);
 }
 
 static gboolean
 meta_frame_right_click_event(MetaUIFrame     *frame,
                              GdkEventButton  *event)
 {
-  meta_core_show_window_menu (gdk_display,
-                              frame->xwindow,
-                              event->x_root,
-                              event->y_root,
-                              event->button,
-                              event->time);
-  return TRUE;
+  int action = meta_prefs_get_action_right_click_titlebar();
+  
+  return meta_frame_titlebar_event (frame, event, action);
 }
 
 static gboolean
