@@ -36,7 +36,6 @@
 #include <gdk-pixbuf/gdk-pixbuf.h>
 
 typedef struct _MetaGroup MetaGroup;
-typedef struct _MetaStruts MetaStruts;
 
 typedef gboolean (*MetaWindowForeachFunc) (MetaWindow *window,
                                            void       *data);
@@ -67,15 +66,6 @@ typedef enum {
   META_CLIENT_TYPE_MAX_RECOGNIZED = 2
 } MetaClientType;
 
-struct _MetaStruts
-{
-  /* struts */
-  MetaRectangle left;
-  MetaRectangle right;
-  MetaRectangle top;
-  MetaRectangle bottom;
-};
-
 struct _MetaWindow
 {
   MetaDisplay *display;
@@ -276,7 +266,7 @@ struct _MetaWindow
   guint calc_placement : 1;
 
   /* Note: can be NULL */
-  MetaStruts *struts;
+  GSList *struts;
 
   /* Transient parent is a root window */
   guint transient_parent_is_root_window : 1;
@@ -318,6 +308,9 @@ struct _MetaWindow
   /* set to the most recent user-interaction event timestamp that we
      know about for this window */
   guint32 net_wm_user_time;
+
+  /* window that gets updated net_wm_user_time values */
+  Window user_time_window;
   
   /* The size we set the window to last (i.e. what we believe
    * to be its actual size on the server). The x, y are
